@@ -18,11 +18,11 @@ class BaseRequestValidator:
         self.db = db
 
     async def validate_request(self, request: Request):
-        if not is_secure_transport(request.url):
-            raise InsecureTransportError()
+        if not is_secure_transport(request):
+            raise InsecureTransportError(request=request)
 
         if request.method not in self.allowed_methods:
             headers = CaseInsensitiveDict(
                 {**default_headers, "allow": ", ".join(self.allowed_methods)}
             )
-            raise MethodNotAllowedError(headers=headers)
+            raise MethodNotAllowedError(request=request, headers=headers)
